@@ -10,6 +10,7 @@ from __future__ import division
 import collections
 import contextlib
 import errno
+import glob
 import io
 import os
 import pprint
@@ -171,6 +172,7 @@ class TestSystemVirtualMemory(unittest.TestCase):
             free_value, psutil_value, delta=MEMORY_TOLERANCE,
             msg='%s %s \n%s' % (free_value, psutil_value, free.output))
 
+    @unittest.skipIf(TRAVIS, "unreliable on TRAVIS")
     @retry_before_failing()
     def test_free(self):
         # _, _, free_value, _ = free_physmem()
@@ -536,6 +538,28 @@ class TestSystemCPU(unittest.TestCase):
             self.assertIsNone(psutil._pslinux.cpu_count_physical())
             assert m.called
 
+    def test_cpu_freq_no_result(self):
+        with mock.patch("psutil._pslinux.glob.glob", return_value=[]):
+            self.assertIsNone(psutil.cpu_freq())
+
+    @unittest.skipIf(TRAVIS, "fails on Travis")
+    def test_cpu_freq_use_second_file(self):
+        # https://github.com/giampaolo/psutil/issues/981
+        def glob_mock(pattern):
+            if pattern.startswith("/sys/devices/system/cpu/cpufreq/policy"):
+                flags.append(None)
+                return []
+            else:
+                flags.append(None)
+                return orig_glob(pattern)
+
+        flags = []
+        orig_glob = glob.glob
+        with mock.patch("psutil._pslinux.glob.glob", side_effect=glob_mock,
+                        create=True):
+            assert psutil.cpu_freq()
+            self.assertEqual(len(flags), 2)
+
 
 # =====================================================================
 # --- system CPU stats
@@ -1043,7 +1067,10 @@ class TestSensorsBattery(unittest.TestCase):
         out = sh("acpi -b")
         if 'unknown' in out.lower():
             return unittest.skip("acpi output not reliable")
-        plugged = "Charging" in out.split('\n')[0]
+        if 'discharging at zero rate' in out:
+            plugged = True
+        else:
+            plugged = "Charging" in out.split('\n')[0]
         self.assertEqual(psutil.sensors_battery().power_plugged, plugged)
 
     def test_emulate_power_plugged(self):
@@ -1174,6 +1201,26 @@ class TestSensorsBattery(unittest.TestCase):
             assert m.called
 
 
+@unittest.skipUnless(LINUX, "LINUX only")
+class TestSensorsTemperatures(unittest.TestCase):
+
+    @unittest.skipIf(TRAVIS, "unreliable on TRAVIS")
+    def test_emulate_eio_error(self):
+        def open_mock(name, *args, **kwargs):
+            if name.endswith("_input"):
+                raise OSError(errno.EIO, "")
+            else:
+                return orig_open(name, *args, **kwargs)
+
+        orig_open = open
+        patch_point = 'builtins.open' if PY3 else '__builtin__.open'
+        with mock.patch(patch_point, side_effect=open_mock) as m:
+            with warnings.catch_warnings(record=True) as ws:
+                self.assertEqual(psutil.sensors_temperatures(), {})
+                assert m.called
+                self.assertIn("ignoring", str(ws[0].message))
+
+
 # =====================================================================
 # --- test process
 # =====================================================================
